@@ -6,7 +6,7 @@ from .electronic_distribution import ElectronicDistribution
 from .periodic_table import PeriodicTable
 from .constants import Constants
 from .softwares import Softwares
-from .exchange_correlation import ExchangeCorreltion
+from .exchange_correlation import ExchangeCorrelation
 from .calculation_code import CalculationCode
 from .minushalf_yaml_default_configuration import (
     VaspDefaultParams,
