@@ -15,6 +15,13 @@ class CalculationCode(Enum):
     def __str__(self):
         return str(self.name)
 
+    @staticmethod
+    def get_default():
+        """
+        Returns the default value for this parameter
+        """
+        return CalculationCode.ae.value
+
     @staticmethod
     def to_list():
         """
