@@ -23,6 +23,13 @@ class CorrectionCode(Enum):
     def __str__(self):
         return str(self.name)
 
+    @staticmethod
+    def get_default():
+        """
+        Returns the default value for this parameter
+        """
+        return CorrectionCode.v.value
+
     @staticmethod
     def to_list():
         """
