@@ -16,6 +16,13 @@ class Softwares(Enum):
     def __str__(self):
         return str(self.name)
 
+    @staticmethod
+    def get_default():
+        """
+        Returns the default value for this parameter
+        """
+        return Softwares.vasp.value
+
     @staticmethod
     def to_list():
         """
