@@ -1,4 +1,4 @@
 """
 Init file for software factory
 """
-from .vasp_factory import VaspFactory
+from .vasp_factory import Vasp
