@@ -1,8 +1,6 @@
 """
 Init file for utils module
 """
-from .input_file import InputFile
-from .vtotal import Vtotal
 from .cli_messages import welcome_message, end_message
 from .drop_comments import drop_comments
 from .parse_valence_orbital_line import parse_valence_orbitals
@@ -15,9 +13,8 @@ from .check_file_exists import (check_eigenval_exists, check_vasprun_exists,
                                 check_procar_exists, check_potcar_exists,
                                 check_outcar_exists)
 from .parse_cut import parse_cut
-from .minushalf_yaml import MinushalfYaml
-from .make_minushalf_results import make_minushalf_results
 from .negative_band_gap import find_negative_band_gap
 from .fractionary_correction_indexes import get_fractionary_correction_indexes
 from .simple_correction_indexes import get_simple_correction_indexes
 from .cut_initial_guess import CutInitialGuess
+from .get_correction_params import get_valence_correction_params, get_conduction_correction_params
